@@ -1,4 +1,4 @@
-/* $ID: image.h, last updated 2019-06-22, F.Osorio */
+/* $ID: image.h, last updated 2020-06-19, F.Osorio */
 
 #ifndef IMAGE_H
 #define IMAGE_H
@@ -19,6 +19,6 @@ extern void sqrtgamma_noise(double *, int *, int *, int *, double *);
 extern void unif_speckle(double *, int *, int *, int *, double *);
 
 /* routines to remove noise */
-extern void F77_NAME(denoise)(double *, int *, int *, int *, double *, int *, double *, int *);
+extern void F77_NAME(denoise)(double *, int *, int *, int *, double *, int *, double *, double *, int *);
 
 #endif /* IMAGE_H */
